# リリースポリシー

## バージョン管理

- 安定したタグ: `vX.Y.Z`
- プレリリースタグ: `vX.Y.Z-rc.N`

## リリースパイプライン

1. クオリティゲート
2. アーティファクトを構築する
3.PyPIを公開する
4. GitHub リリースの作成
5. `main` へのプッシュでドキュメントを公開する

## 変更履歴

従来のコミットと厳選されたリリースノートから生成されます。